# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Mail-SPF
Version:	3.20240923
Release:	1.%{__distinit}%{__distvers}
Summary:	Object-oriented implementation of Sender Policy Framework
License:	BSD-3-Clause
URL:		https://metacpan.org/release/Mail-SPF
Source0:	https://cpan.metacpan.org/modules/by-module/Mail/Mail-SPF-%{version}.tar.gz
Patch1:		Mail-SPF-3.20240827-testsuite.patch
Patch2:		Mail-SPF-v2.9.0-empty-domain-label.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(constant)
BuildRequires:	perl(Error)
BuildRequires:	perl(Net::DNS) >= 0.63
BuildRequires:	perl(Net::DNS::Resolver)
BuildRequires:	perl(NetAddr::IP) >= 4
BuildRequires:	perl(overload)
BuildRequires:	perl(strict)
BuildRequires:	perl(Sys::Hostname)
BuildRequires:	perl(URI::Escape) >= 1.13
BuildRequires:	perl(utf8)
BuildRequires:	perl(version)
BuildRequires:	perl(warnings)
# Script Runtime
BuildRequires:	perl(Getopt::Long)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IO::Socket::INET)
BuildRequires:	perl(IO::Socket::UNIX)
BuildRequires:	perl(Socket)
# Test Suite
BuildRequires:	perl(blib)
BuildRequires:	perl(Mail::SPF::Test)
BuildRequires:	perl(Net::DNS::Resolver::Programmable)
BuildRequires:	perl(Net::DNS::RR)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Test::Pod) >= 1.00
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(IO::Socket::INET)
Requires:	perl(IO::Socket::UNIX)
Requires:	perl(Net::DNS) >= 0.63
Requires:	perl(URI::Escape) >= 1.13

Requires(post):		/usr/sbin/alternatives
Requires(preun):	/usr/sbin/alternatives
Requires(postun):	/usr/sbin/alternatives, /usr/bin/readlink

%description
Mail::SPF is an object-oriented implementation of Sender Policy Framework
(SPF). See http://www.openspf.org for more information about SPF.

%prep
%setup -q -n Mail-SPF-%{version}

# Work around test suite failures with Net::DNS ≥ 0.68 (CPAN RT#78214)
%patch -P 1 -b .tests

# And another one, with empty domain labels
%patch -P 2

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

# Rename spfquery and spfd for alternatives support
mv %{buildroot}%{_bindir}/spfquery		%{buildroot}%{_bindir}/spfquery.Mail::SPF
mv %{buildroot}%{_bindir}/spfd			%{buildroot}%{_bindir}/spfd.Mail::SPF
mv %{buildroot}%{_mandir}/man1/spfd.1		%{buildroot}%{_mandir}/man1/spfd.Mail::SPF.1
mv %{buildroot}%{_mandir}/man1/spfquery.1	%{buildroot}%{_mandir}/man1/spfquery.Mail::SPF.1
# spfd needs to be executable
chmod -c +x %{buildroot}%{_bindir}/spfd.Mail::SPF
# Create %%ghost files for alternatives targets 
touch %{buildroot}%{_bindir}/spfquery 
chmod -c +x %{buildroot}%{_bindir}/spfquery 
touch %{buildroot}%{_bindir}/spfd 
chmod -c +x %{buildroot}%{_bindir}/spfd 
touch %{buildroot}%{_mandir}/man1/spfd.1 
touch %{buildroot}%{_mandir}/man1/spfquery.1 

%check
make test

%post
/usr/sbin/alternatives \
	--install	%{_bindir}/spfquery		spf		%{_bindir}/spfquery.Mail::SPF 60 \
	--slave		%{_bindir}/spfd			spf-daemon	%{_bindir}/spfd.Mail::SPF \
	--slave		%{_mandir}/man1/spfd.1.gz	spf-daemon-man	%{_mandir}/man1/spfd.Mail::SPF.1.gz \
	--slave		%{_mandir}/man1/spfquery.1.gz	spf-man		%{_mandir}/man1/spfquery.Mail::SPF.1.gz
exit 0

%preun
if [ $1 = 0 ]; then
	/usr/sbin/alternatives --remove spf %{_bindir}/spfquery.Mail::SPF
fi

%postun
if [ "$1" -ge "1" ]; then
	spf=`readlink /etc/alternatives/spf`
	if [ "$spf" == "%{_bindir}/spfquery.Mail::SPF" ]; then
		/usr/sbin/alternatives --set spf %{_bindir}/spfquery.Mail::SPF
	fi
fi

%files
%license LICENSE
%doc Changes README TODO
%ghost %{_bindir}/spfd 
%ghost %{_bindir}/spfquery 
%{_bindir}/spfd.Mail::SPF
%{_bindir}/spfquery.Mail::SPF
%{perl_vendorlib}/Mail/
%ghost %{_mandir}/man1/spfd.1.gz
%ghost %{_mandir}/man1/spfquery.1.gz
%{_mandir}/man1/spfd.Mail::SPF.1.gz
%{_mandir}/man1/spfquery.Mail::SPF.1.gz
%{_mandir}/man3/Mail::SPF.3*
%{_mandir}/man3/Mail::SPF::Base.3*
%{_mandir}/man3/Mail::SPF::Exception.3*
%{_mandir}/man3/Mail::SPF::MacroString.3*
%{_mandir}/man3/Mail::SPF::Mech.3*
%{_mandir}/man3/Mail::SPF::Mech::A.3*
%{_mandir}/man3/Mail::SPF::Mech::All.3*
%{_mandir}/man3/Mail::SPF::Mech::Exists.3*
%{_mandir}/man3/Mail::SPF::Mech::IP4.3*
%{_mandir}/man3/Mail::SPF::Mech::IP6.3*
%{_mandir}/man3/Mail::SPF::Mech::Include.3*
%{_mandir}/man3/Mail::SPF::Mech::MX.3*
%{_mandir}/man3/Mail::SPF::Mech::PTR.3*
%{_mandir}/man3/Mail::SPF::Mod.3*
%{_mandir}/man3/Mail::SPF::Mod::Exp.3*
%{_mandir}/man3/Mail::SPF::Mod::Redirect.3*
%{_mandir}/man3/Mail::SPF::Record.3*
%{_mandir}/man3/Mail::SPF::Request.3*
%{_mandir}/man3/Mail::SPF::Result.3*
%{_mandir}/man3/Mail::SPF::SenderIPAddrMech.3*
%{_mandir}/man3/Mail::SPF::Server.3*
%{_mandir}/man3/Mail::SPF::Term.3*
%{_mandir}/man3/Mail::SPF::Util.3*
%{_mandir}/man3/Mail::SPF::v1::Record.3*
%{_mandir}/man3/Mail::SPF::v2::Record.3*

%changelog
* Mon Sep 23 2024 Paul Howarth <paul@city-fan.org> - 3.20240923-1
- Update to 3.20240923
  - Fix issue where certain DNS results would cause an exception to be thrown

* Tue Aug 27 2024 Paul Howarth <paul@city-fan.org> - 3.20240827-1
- Update to 3.20240827
  - Do not try to parse an IPv4 address unnecessarily
  - Import RFC7208 tests
  - Referencing the same TXT record through multiple CNAME aliases is not
    permitted by RFC7208
  - Make it clear that BlackMagic module is not available
  - Fix checks for IPv4-mapped IPv6 connections
  - Cache DNS results
  - Misc dzil/build/ci improvements
  - SPF explanation text is restricted to 7-bit ascii

* Mon Jun 17 2024 Paul Howarth <paul@city-fan.org> - 3.20240617-1
- Update to 3.20240617
  - Update INSTALL file for Dist::Zilla changes
  - Fix memory leak in Mail::SPF::Server when cacheing a Mail::SPF::MacroString
  - When mfrom is empty, create a synthetic mfrom (postmaster@helo) and check
    that identity using the mfrom scope as specified in RFC7208
  - Fix missing declare in Mail::SPF::Server
  - Require Mail::SPF::Mech when needed
  - Correctly handle empty labels
  - Use "try" instead of "eval"
  - Error out if the lookup fails

* Tue Feb  6 2024 Paul Howarth <paul@city-fan.org> - 3.20240206-1
- Update to 3.20240206
  - Remove signature file from distribution

* Mon Feb  5 2024 Paul Howarth <paul@city-fan.org> - 3.20240205-2
- Fix use of alternatives in %%post

* Mon Feb  5 2024 Paul Howarth <paul@city-fan.org> - 3.20240205-1
- Update to 3.20240205
  - Fix pod in Mail::SPF::Util (CPAN RT#93241)
  - Fix "char_str_list is not a valid sub" in new Net::DNS (CPAN RT#149825)
  - BREAKING CHANGE: spfd is now installed in /bin instead of /sbin; as a
    result, Mail::SPF now respects an install prefix and may more easily be
    installed in a non root and/or local lib environment
- Use author-independent source URL
- Switch to ExtUtils::MakeMaker flow

* Wed Mar 29 2023 Paul Howarth <paul@city-fan.org> - 2.9.0-30
- Use SPDX-format license tag
- Avoid deprecated patch syntax
- Use %%license unconditionally

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 2.9.0-19
- Perl 5.30 rebuild

* Fri Apr 27 2018 Paul Howarth <paul@city-fan.org> - 2.9.0-15
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Sat Sep  3 2016 Paul Howarth <paul@city-fan.org> - 2.9.0-10
- Classify buildreqs by usage

* Sun Sep 14 2014 Paul Howarth <paul@city-fan.org> - 2.9.0-5
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Fri Dec 20 2013 Paul Howarth <paul@city-fan.org> - 2.9.0-2
- Avoid the empty domain label test, which now breaks the test suite

* Mon Jul 22 2013 Paul Howarth <paul@city-fan.org> - 2.9.0-1
- Update to 2.9.0
  - Default to querying only TXT type RRs
    (query_rr_types = Mail::SPF::Server->query_rr_type_txt); experience has
    shown that querying SPF type RRs is impractical

* Fri Jun 28 2013 Paul Howarth <paul@city-fan.org> - 2.8.0-3
- Fix broken POD (CPAN RT#86060)
- Work around test suite failures with Net::DNS ≥ 0.68 (CPAN RT#78214)

* Thu Jul  5 2012 Paul Howarth <paul@city-fan.org> - 2.8.0-2
- BR: perl(base), perl(constant), perl(Net::DNS::RR) and perl(URI::Escape)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Always run the full test suite
  - Don't need to run the test suite with LC_ALL=C
  - Don't need to define %%{perl_vendorlib}
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Mon Jan 30 2012 Paul Howarth <paul@city-fan.org> - 2.8.0-1
- Update to 2.8.0
  - Sanitize result local_explanation (as well as result object string
    representation) by replacing all non-printable or non-ascii characters with
    their hex-escaped representation, e.g. "\x00" (bugs.launchpad.net #806926)
  - Change openspf.org URLs to openspf.net because openspf.org is unreachable
    indefinitely
  - Change http://www.ietf.org/rfc/….txt URLs to http://tools.ietf.org/html/…
  - META.yml: configure_requires: Module::Build 0.2805
  - META.yml: requires: Net::DNS 0.62 (was: 0.52) (CPAN RT#28545)
  - META.yml: Revert to flat version numbers for perl and
    Net::DNS::Resolver::Programmable build requirements to avoid
    Module::Build::Compat/Makefile.PL incompatibilities (CPAN RT#53231)
  - Attempt to prevent a cascading failure in t/00.03-class-result.t that seems
    to happen under rare, unknown circumstances (CPAN RT#39099)

* Tue Jun 28 2011 Paul Howarth <paul@city-fan.org> - 2.007-5
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 2.007-4
- Rebuild for perl 5.12.1 in Rawhide

* Fri Jun  4 2010 Paul Howarth <paul@city-fan.org> - 2.007-3
- Fix dist tag for RHEL-6 Beta

* Fri Mar  5 2010 Paul Howarth <paul@city-fan.org> - 2.007-2
- Dist tag for Rawhide no longer needs special-casing

* Mon Nov  2 2009 Paul Howarth <paul@city-fan.org> - 2.007-1
- Update to 2.007 (see CHANGES for details)

* Fri Sep 18 2009 Paul Howarth <paul@city-fan.org> - 2.006-2
- Define RPM macros in global scope
- %%ghost alternatives targets 
- %%postun requires /usr/bin/readlink

* Thu Oct 16 2008 Paul Howarth <paul@city-fan.org> - 2.006-1
- Import from Fedora
- Update to 2.006
- Include spfquery and spfd with alternatives support
- Buildreq Module::Build >= 0.26
- Buildreq and Req Net::DNS >= 0.63 (CPAN RT#28545)

* Thu Mar 06 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 2.005-2
- Rebuild for new perl

* Mon Jul 09 2007 Steven Pritchard <steve@kspei.com> 2.005-1
- Specfile autogenerated by cpanspec 1.71.
- Add the "v" before version numbers to handle broken upstream packaging.
- Remove redundant perl build dependency.
- Drop bogus version number from Net::DNS::Resolver::Programmable dependency.
- Drop redundant explicit dependencies.
- BR Test::More and Test::Pod.
- Include the spfd and spfquery scripts as %%doc
